==> scibd-0.1.1.tar.gz: scibd-0.1.1/setup.py <==
#!/usr/bin/env python
# coding:utf-8

# from setuptools import find_packages, setup
# # from setuptools import find_packages, setup, Command

# setup(
#     name='scibd',
#     version='1.0',
#     description='A doublet detetion tool for scCAS data',
#     long_description=open('README.rst').read(),
#     author='Wenhao Zhang',
#     author_email='23220210156258@stu.xmu.edu.cn',
#     maintainer='Wenhao Zhang',
#     maintainer_email='23220210156258@stu.xmu.edu.cn',
#     packages=find_packages(),
# #     install_requires = [
# #     "annoy~=1.17.0",
# #     "matplotlib~=3.5.1",
# #     "numpy~=1.22.4",
# #     "pandas~=1.3.1",
# #     "psutil~=5.8.0",
# #     "scanpy~=1.9.1",
# #     "scikit_bio~=0.5.8",
# #     "scikit_learn~=1.2.0",
# #     "scipy~=1.7.1",
# #     "seaborn~=0.11.1",
# #     "umap_learn~=0.5.1",
# #     ],
#     platforms=["all"],
#     url='https://github.com/Ying-Lab/scIBD/',
#     license='MIT',
#     classifiers=[
#         'Development Status :: 4 - Beta',
#         'Operating System :: OS Independent',
#         'Intended Audience :: Developers',
#         'License :: OSI Approved :: MIT License',
#         'Programming Language :: Python',
#         'Programming Language :: Python :: 3.8',
#         'Programming Language :: Python :: Implementation :: CPython',
#         'Programming Language :: Python :: Implementation :: PyPy'
#     ],
# )

#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Note: To use the 'upload' functionality of this file, you must:
#   $ pipenv install twine --dev

import io
import os
import sys
from shutil import rmtree

from setuptools import find_packages, setup, Command

# Package meta-data.
NAME = 'scibd'
DESCRIPTION = 'A doublet detetion tool for scCAS data.'
URL = 'https://github.com/Ying-Lab/scIBD/'
EMAIL = '23220210156258@stu.xmu.edu.cn'
AUTHOR = 'Wenhao Zhang'
REQUIRES_PYTHON = '==3.8.0'
VERSION = '0.1.1'

# What packages are required for this module to be executed?
REQUIRED = [
    # 'requests', 'maya', 'records',
]

# What packages are optional?
EXTRAS = {
    # 'fancy feature': ['django'],
}

# The rest you shouldn't have to touch too much :)
# ------------------------------------------------
# Except, perhaps the License and Trove Classifiers!
# If you do change the License, remember to change the Trove Classifier for that!

here = os.path.abspath(os.path.dirname(__file__))

# Import the README and use it as the long-description.
# Note: this will only work if 'README.md' is present in your MANIFEST.in file!
try:
    with io.open(os.path.join(here, 'README.md'), encoding='utf-8') as f:
        long_description = '\n' + f.read()
except FileNotFoundError:
    long_description = DESCRIPTION

# Load the package's __version__.py module as a dictionary.
about = {}
if not VERSION:
    project_slug = NAME.lower().replace("-", "_").replace(" ", "_")
    with open(os.path.join(here, project_slug, '__version__.py')) as f:
        exec(f.read(), about)
else:
    about['__version__'] = VERSION


class UploadCommand(Command):
    """Support setup.py upload."""

    description = 'Build and publish the package.'
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print('\033[1m{0}\033[0m'.format(s))

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        try:
            self.status('Removing previous builds…')
            rmtree(os.path.join(here, 'dist'))
        except OSError:
            pass

        self.status('Building Source and Wheel (universal) distribution…')
        os.system('{0} setup.py sdist bdist_wheel --universal'.format(sys.executable))

        self.status('Uploading the package to PyPI via Twine…')
        os.system('twine upload dist/*')

        self.status('Pushing git tags…')
        os.system('git tag v{0}'.format(about['__version__']))
        os.system('git push --tags')

        sys.exit()


# Where the magic happens:
setup(
    name=NAME,
    version=about['__version__'],
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type='text/markdown',
    author=AUTHOR,
    author_email=EMAIL,
    python_requires=REQUIRES_PYTHON,
    url=URL,
    packages=find_packages(exclude=["tests", "*.tests", "*.tests.*", "tests.*"]),
    # If your package is a single module, use this instead of 'packages':
    # py_modules=['mypackage'],

    # entry_points={
    #     'console_scripts': ['mycli=mymodule:cli'],
    # },
    install_requires=REQUIRED,
    extras_require=EXTRAS,
    include_package_data=True,
    license='MIT',
    classifiers=[
        # Trove classifiers
        # Full list: https://pypi.python.org/pypi?%3Aaction=list_classifiers
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy'
    ],
    # $ setup.py publish support.
    cmdclass={
        'upload': UploadCommand,
    },
)

==> scibd-0.1.3.tar.gz: scibd-0.1.3/setup.py <==
#!/usr/bin/env python
# coding:utf-8

# from setuptools import find_packages, setup
# # from setuptools import find_packages, setup, Command

# setup(
#     name='scibd',
#     version='1.0',
#     description='A doublet detetion tool for scCAS data',
#     long_description=open('README.rst').read(),
#     author='Wenhao Zhang',
#     author_email='23220210156258@stu.xmu.edu.cn',
#     maintainer='Wenhao Zhang',
#     maintainer_email='23220210156258@stu.xmu.edu.cn',
#     packages=find_packages(),
# #     install_requires = [
# #     "annoy~=1.17.0",
# #     "matplotlib~=3.5.1",
# #     "numpy~=1.22.4",
# #     "pandas~=1.3.1",
# #     "psutil~=5.8.0",
# #     "scanpy~=1.9.1",
# #     "scikit_bio~=0.5.8",
# #     "scikit_learn~=1.2.0",
# #     "scipy~=1.7.1",
# #     "seaborn~=0.11.1",
# #     "umap_learn~=0.5.1",
# #     ],
#     platforms=["all"],
#     url='https://github.com/Ying-Lab/scIBD/',
#     license='MIT',
#     classifiers=[
#         'Development Status :: 4 - Beta',
#         'Operating System :: OS Independent',
#         'Intended Audience :: Developers',
#         'License :: OSI Approved :: MIT License',
#         'Programming Language :: Python',
#         'Programming Language :: Python :: 3.8',
#         'Programming Language :: Python :: Implementation :: CPython',
#         'Programming Language :: Python :: Implementation :: PyPy'
#     ],
# )

#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Note: To use the 'upload' functionality of this file, you must:
#   $ pipenv install twine --dev

import io
import os
import sys
from shutil import rmtree

from setuptools import find_packages, setup, Command

# Package meta-data.
NAME = 'scibd'
DESCRIPTION = 'A doublet detetion tool for scCAS data. https://github.com/Ying-Lab/scIBD'
URL = 'https://github.com/Ying-Lab/scIBD/'
EMAIL = '23220210156258@stu.xmu.edu.cn'
AUTHOR = 'Wenhao Zhang'
REQUIRES_PYTHON = '>=3.8.0'
VERSION = '0.1.3'

# What packages are required for this module to be executed?
REQUIRED = [
    # 'requests', 'maya', 'records',
]

# What packages are optional?
EXTRAS = {
    # 'fancy feature': ['django'],
}

# The rest you shouldn't have to touch too much :)
# ------------------------------------------------
# Except, perhaps the License and Trove Classifiers!
# If you do change the License, remember to change the Trove Classifier for that!

here = os.path.abspath(os.path.dirname(__file__))

# Import the README and use it as the long-description.
# Note: this will only work if 'README.md' is present in your MANIFEST.in file!
try:
    with io.open(os.path.join(here, 'README.md'), encoding='utf-8') as f:
        long_description = '\n' + f.read()
except FileNotFoundError:
    long_description = DESCRIPTION

# Load the package's __version__.py module as a dictionary.
about = {}
if not VERSION:
    project_slug = NAME.lower().replace("-", "_").replace(" ", "_")
    with open(os.path.join(here, project_slug, '__version__.py')) as f:
        exec(f.read(), about)
else:
    about['__version__'] = VERSION


class UploadCommand(Command):
    """Support setup.py upload."""

    description = 'Build and publish the package.'
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print('\033[1m{0}\033[0m'.format(s))

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        try:
            self.status('Removing previous builds…')
            rmtree(os.path.join(here, 'dist'))
        except OSError:
            pass

        self.status('Building Source and Wheel (universal) distribution…')
        os.system('{0} setup.py sdist bdist_wheel --universal'.format(sys.executable))

        self.status('Uploading the package to PyPI via Twine…')
        os.system('twine upload dist/*')

        self.status('Pushing git tags…')
        os.system('git tag v{0}'.format(about['__version__']))
        os.system('git push --tags')

        sys.exit()


# Where the magic happens:
setup(
    name=NAME,
    version=about['__version__'],
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type='text/markdown',
    author=AUTHOR,
    author_email=EMAIL,
    python_requires=REQUIRES_PYTHON,
    url=URL,
    packages=find_packages(exclude=["tests", "*.tests", "*.tests.*", "tests.*"]),
    # If your package is a single module, use this instead of 'packages':
    # py_modules=['mypackage'],

    # entry_points={
    #     'console_scripts': ['mycli=mymodule:cli'],
    # },
    install_requires=REQUIRED,
    extras_require=EXTRAS,
    include_package_data=True,
    license='MIT',
    classifiers=[
        # Trove classifiers
        # Full list: https://pypi.python.org/pypi?%3Aaction=list_classifiers
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy'
    ],
    # $ setup.py publish support.
    cmdclass={
        'upload': UploadCommand,
    },
)
